{{ fullname | escape | underline}}

.. currentmodule:: {{ module }}

.. autofunction:: {{ module }}.{{ objname }}

.. _sphx_glr_backreferences_{{ module }}.{{ objname }}:

.. minigallery:: {{ module }}.{{ objname }}
   :add-heading: Gallery examples
   :heading-level: -